#convert identifier from Python to original_edgelist

convert_id_Python2edgelist <- function(PythonID_vector,edgelist_filename,disconn_id){
  #converts the identifiers in Python edgeprobability lists to identifiers as used in the original edgelist
  #note that since the edge list was designed for use with Python, identifiers also started at 0. Therefore, in order to
  # retrieve the correct index of the associated correlation matrix, please add "1" to the converted indices.
  #
  #Input
  #------------
  #- PythonID_vector: vector of Python IDs, integer values >=0
  #- edgelist_filename: filename of the edge list which was used for the generation of the network, contains source nodes in column 1, target nodes
  #   in column2
  #- disconn_id: (usually from the same type as the entries in the edge list)
  #
  #Output
  #-------------
  #- vector of the same length as PythonID_vector, Python IDs are replaced by the corresponding IDs from the edge list
  #
  #Example
  #-------------
  ##read in for example an edge confidence score file as produced from calc_edge_prob
  #edgeproblist <- read.table("example_files/metab_example_miss_connedge_prob.txt", sep="\t")
  #colnames(edgeproblist) <- c("source_node","target_node","edge_prob")
  #orig_ID_sources <- convert_id_Python2edgelist(edgeproblist$source_node,"example_files/180905_metabbud_erneg_spear_scalefree.csv",161)
  

  
  edge_list<- read.table(edgelist_filename,sep=",",header=T)
  edge_list_st<- c(t(edge_list[,1:2]))
  edge_list_st<- edge_list_st[-which(duplicated(edge_list_st))] #remove all but first occurrence of a node number
  #the order of edge_list_st is now the order of the Python nodes
  

  #initialize the new object
  converted_id_vector <- rep(0,length(PythonID_vector))
  #note that disconnected nodes (degree = 0) are indistinguishable. 
  #Thus, we would have multiple matches between an index in edgeproblist and a node. Consequently, we set all Python
  #identifiers which are bigger than the number of nodes given in the edge list to "disconn_id". 
  converted_id_vector[PythonID_vector>=length(edge_list_st)] <- disconn_id
  #set the other identifiers
  converted_id_vector[PythonID_vector<length(edge_list_st)] <- edge_list_st[PythonID_vector[PythonID_vector<length(edge_list_st)]+1]
  
  return(converted_id_vector)

}