read_block_levels <- function(filename_start,
                              filename_end,
                              containing_folder,
                              file_no_list,
                              is_hier_SBM,
                              exportno,
                              topmindl,
                              max_hier_level){
  #this function reads the block levels in order of saving (not in the order of topmindl); sorted by minimal DL within the runs
  #skips files which are empty
  #
  #INPUT
  #----------
  #filename_start - filename used for block partitions before iteration index
  #filename_end - filename part after the iteration index for block partition files
  #containing_folder - folder in which the files can be found
  #file_no_list - vector of indices over which has been iterated; needs to be exactly the same size and order as in topmindl
  #exportno - number of best partitions exported from each iteration
  #is_hier_SBM - Boolean, whether the SBM is hierarchical or not, default: FALSE
  #topmindl - list of vectors of minimal description lengths as obtained from read_top_mindl() from results from 
  #max_hier_level - integer, for hierarchical SBM, maximal hierarchy level, default: 20
  # 
  #Output
  #-----------
  #list of partition vectors of integer values indicating the block index, list of list of vectors for hierarchical SBM
  #
  #Example
  #-------------
  # blocks_metabbud_example <- read_block_levels(filename_start="result_file_metab_dchSBM",
  #                                                        filename_end= "",
  #                                                        containing_folder="~/example_files/",
  #                                                        file_no_list=1:10,
  #                                                        is_hier_sbm_=TRUE,
  #                                                        exportno=5,
  #                                                        topmindl = topmindl_metab_example,
  #                                                        max_hier_level=10)
  
  #initialize blockstate container
  #the first for each run file will be the ones with the best (lowest) minimal description length
  blockstate_full <- list(length(file_no_list))
  runind <- 0
  for (i in file_no_list){#for all files which have been written
    runind <- runind+1 #count over fit sets
    sorted_topmindl <- sort(topmindl[[runind]]$V1)
    blockstates <- list()#initialize sublist
    for (j in 1:exportno) {#for all exported, this number has to be given
      if (is_hier_SBM==FALSE) { #if we have non-hierarchical
        blockstates[[j]] <- read.table(paste0(
          containing_folder,
          filename_start,
          i,
          filename_end,"_opt",j-1,"_runind", #-1: account for python starting at 0
          (which(topmindl[[runind]]$V1==sorted_topmindl[j])-1),#running index
          "_top_block_no.txt"),
          header=FALSE)
      }
      else { #if we have hierarchical
        #create a list to take all these
        blocklist=list()
        for (k in 1:max_hier_level) {
          filname <- paste0(containing_folder,filename_start,
                            i,filename_end,"_opt",j-1, #-1: account for python starting at 0
                            "_runind", 
                            which(topmindl[[runind]]$V1==sorted_topmindl[j])-1,#running index
                            "_lev",k-1,"_top_block_no.txt")
          if (file.exists(filname)) {#if the file exists
            blocklist[[k]] <- read.table(filname,
                                         header=FALSE)
          } else { #otherwise, break the loop over the levels
            break }
        }
        blockstates[[j]] <- blocklist #append the list of hierarchy levels to the list
      }
      
      blockstate_full[[runind]] <- blockstates # append that to the overall blockstate list
    }
  }
  return(blockstate_full)
}
